﻿using System.Collections.ObjectModel;
using Microsoft.Practices.Prism.Commands;
using Microsoft.Practices.Prism.Mvvm;

namespace XamDataGrid_Testing
{
	public class MainWindowViewModel : BindableBase
	{
		private DelegateCommand deleteSelectedCommand;

		public DelegateCommand DeleteSelectedCommand
		{
			get { return deleteSelectedCommand ?? (deleteSelectedCommand = new DelegateCommand(DeleteSelected, CanDelete)); }
		}

		private DelegateCommand populateCollectionCommand;

		public DelegateCommand PopulateCollectionCommand
		{
			get { return populateCollectionCommand ?? (populateCollectionCommand = new DelegateCommand(PopulateDeviceCollection)); }
		}

		private bool CanDelete()
		{
			return (selectedDevice != null && deviceCollection != null);
		}

		private void DeleteSelected()
		{
			if (selectedDevice != null && deviceCollection != null)
			{
				deviceCollection.Remove(selectedDevice);
			}
		}

		public MainWindowViewModel()
		{
			PopulateDeviceCollection();
		}

		private void PopulateDeviceCollection()
		{
			DeviceCollection = new ObservableCollection<Device>();

			DeviceCollection.Add(new Device() {Name = "iPhone 4", OEM = "Apple", IsModified = false});
			DeviceCollection.Add(new Device() { Name = "iPhone 4s", OEM = "Apple", IsModified = false });
			DeviceCollection.Add(new Device() { Name = "iPhone 5", OEM = "Apple", IsModified = false });
			DeviceCollection.Add(new Device() { Name = "iPhone 5s", OEM = "Apple", IsModified = false });
			DeviceCollection.Add(new Device() { Name = "Galaxy Nexus", OEM = "Google", IsModified = false });
			DeviceCollection.Add(new Device() { Name = "Nexus One", OEM = "Google", IsModified = false });
			DeviceCollection.Add(new Device() { Name = "Nexus 4", OEM = "Google", IsModified = false });
			DeviceCollection.Add(new Device() { Name = "Nexus 5", OEM = "Google", IsModified = false });
		}

		private ObservableCollection<Device> deviceCollection;
		public ObservableCollection<Device> DeviceCollection
		{
			get { return deviceCollection; }
			set
			{
				deviceCollection = value; 
				OnPropertyChanged(() => DeviceCollection);
				DeleteSelectedCommand.RaiseCanExecuteChanged();
			}
		}

		private Device selectedDevice;
		public Device SelectedDevice
		{
			get { return selectedDevice; }
			set
			{
				selectedDevice = value;
				OnPropertyChanged(() => SelectedDevice);
				DeleteSelectedCommand.RaiseCanExecuteChanged();
			}
		}
	}
}